2.0.1 (2021-04-16) ()
=====================

New Features
------------

-Introduction of the Clippy file management and assistance class.

-Introduction of the Zellars celestial target class.

-Introduction of the Ceres observation data series class.

-Introduction of the Stack observational data stack class.

Other Changes and Additions
---------------------------

-Removed two unused dependencies.

-Moved to python class based operations.

-Removed older example files.

-Development files left in place

-Astoquery.astrometryNet API key moved to astroquery config file

-Dorado now makes its own working directory

Bug Fixes
---------

-File size enlargement has been fixed for Bias frames

0.1.2 (2020-09-14) ()
=====================

New Features
------------

-Organized functions into categorized subpackages.

Other Changes and Additions
---------------------------


Bug Fixes
---------

0.1.1 (2020-08-21) ()
=====================

New Features
------------

-Split functions into categorized subpackages.

Other Changes and Additions
---------------------------

-Added badges to documentation for status of project.

-Added additional documentation.

-Setup version control and packaging logic.

Bug Fixes
---------

0.1.0 (2020-07-26) ()
================

New Features
------------

-Added ability to contact Astrometry.net for plate solving.

Other Changes and Additions
---------------------------

-Changed name from Draco to Dorado in preparation for publishing.

-Added documentation.

-Setup version control and packaging logic.

Bug Fixes
---------

-Fixed setup errors which used local versioning for PyPi which would result in an error on twine submit.

0.1.0 (2020-07-26)
================

- Initial release.
